@@ -1,6 +1,6 @@
 {-# LANGUAGE OverloadedStrings #-}
 -- | Build time configuration used during code generation.
-module GI.GLib.Config ( overrides ) where
+module GI.GLib.Config ( overrides, modules ) where
 
 import qualified Data.Text as T
 import Data.Text (Text)
@@ -633,3 +633,95 @@ overrides = T.unlines
  , "set-attr GLib/variant_type_string_scan/@parameters/limit nullable 1"
  , "set-attr GLib/warn_message/@parameters/domain nullable 1"
  , "set-attr GLib/warn_message/@parameters/warnexpr nullable 1"]
+
+-- | Modules in this package
+modules :: [Text]
+modules =  [ "GI.GLib.Config"
+ , "GI.GLib"
+ , "GI.GLib.Callbacks"
+ , "GI.GLib.Constants"
+ , "GI.GLib.Enums"
+ , "GI.GLib.Flags"
+ , "GI.GLib.Functions"
+ , "GI.GLib.Structs"
+ , "GI.GLib.Structs.Allocator"
+ , "GI.GLib.Structs.AsyncQueue"
+ , "GI.GLib.Structs.BookmarkFile"
+ , "GI.GLib.Structs.ByteArray"
+ , "GI.GLib.Structs.Bytes"
+ , "GI.GLib.Structs.Cache"
+ , "GI.GLib.Structs.Checksum"
+ , "GI.GLib.Structs.Completion"
+ , "GI.GLib.Structs.Cond"
+ , "GI.GLib.Structs.Data"
+ , "GI.GLib.Structs.Date"
+ , "GI.GLib.Structs.DateTime"
+ , "GI.GLib.Structs.DebugKey"
+ , "GI.GLib.Structs.Dir"
+ , "GI.GLib.Structs.HashTableIter"
+ , "GI.GLib.Structs.Hmac"
+ , "GI.GLib.Structs.Hook"
+ , "GI.GLib.Structs.HookList"
+ , "GI.GLib.Structs.IOChannel"
+ , "GI.GLib.Structs.IOFuncs"
+ , "GI.GLib.Structs.KeyFile"
+ , "GI.GLib.Structs.LogField"
+ , "GI.GLib.Structs.MainContext"
+ , "GI.GLib.Structs.MainLoop"
+ , "GI.GLib.Structs.MappedFile"
+ , "GI.GLib.Structs.MarkupParseContext"
+ , "GI.GLib.Structs.MarkupParser"
+ , "GI.GLib.Structs.MatchInfo"
+ , "GI.GLib.Structs.MemChunk"
+ , "GI.GLib.Structs.MemVTable"
+ , "GI.GLib.Structs.Node"
+ , "GI.GLib.Structs.Once"
+ , "GI.GLib.Structs.OptionContext"
+ , "GI.GLib.Structs.OptionEntry"
+ , "GI.GLib.Structs.OptionGroup"
+ , "GI.GLib.Structs.PathBuf"
+ , "GI.GLib.Structs.PatternSpec"
+ , "GI.GLib.Structs.PollFD"
+ , "GI.GLib.Structs.PtrArray"
+ , "GI.GLib.Structs.Queue"
+ , "GI.GLib.Structs.RWLock"
+ , "GI.GLib.Structs.Rand"
+ , "GI.GLib.Structs.RecMutex"
+ , "GI.GLib.Structs.Regex"
+ , "GI.GLib.Structs.Relation"
+ , "GI.GLib.Structs.Scanner"
+ , "GI.GLib.Structs.ScannerConfig"
+ , "GI.GLib.Structs.Sequence"
+ , "GI.GLib.Structs.SequenceIter"
+ , "GI.GLib.Structs.Source"
+ , "GI.GLib.Structs.SourceCallbackFuncs"
+ , "GI.GLib.Structs.SourceFuncs"
+ , "GI.GLib.Structs.StatBuf"
+ , "GI.GLib.Structs.String"
+ , "GI.GLib.Structs.StringChunk"
+ , "GI.GLib.Structs.StrvBuilder"
+ , "GI.GLib.Structs.TestCase"
+ , "GI.GLib.Structs.TestConfig"
+ , "GI.GLib.Structs.TestLogBuffer"
+ , "GI.GLib.Structs.TestLogMsg"
+ , "GI.GLib.Structs.TestSuite"
+ , "GI.GLib.Structs.Thread"
+ , "GI.GLib.Structs.ThreadPool"
+ , "GI.GLib.Structs.TimeVal"
+ , "GI.GLib.Structs.TimeZone"
+ , "GI.GLib.Structs.Timer"
+ , "GI.GLib.Structs.TrashStack"
+ , "GI.GLib.Structs.Tree"
+ , "GI.GLib.Structs.TreeNode"
+ , "GI.GLib.Structs.Tuples"
+ , "GI.GLib.Structs.UnixPipe"
+ , "GI.GLib.Structs.Uri"
+ , "GI.GLib.Structs.UriParamsIter"
+ , "GI.GLib.Structs.VariantBuilder"
+ , "GI.GLib.Structs.VariantDict"
+ , "GI.GLib.Structs.VariantType"
+ , "GI.GLib.Unions"
+ , "GI.GLib.Unions.DoubleIEEE754"
+ , "GI.GLib.Unions.FloatIEEE754"
+ , "GI.GLib.Unions.Mutex"
+ , "GI.GLib.Unions.TokenValue"]
