@@ -5,7 +5,7 @@
 -- License    : LGPL-2.1
 -- Maintainer : Iñaki García Etxebarria
 -- 
--- Contains the public fields of a GByteArray.
+-- Contains the public fields of a @GByteArray@.
 
 #if (MIN_VERSION_haskell_gi_overloading(1,0,0) && !defined(__HADDOCK_VERSION__))
 #define ENABLE_OVERLOADING
@@ -30,11 +30,6 @@ module GI.GLib.Structs.ByteArray
     byteArrayAppend                         ,
 
 
--- ** free #method:free#
-
-    byteArrayFree                           ,
-
-
 -- ** freeToBytes #method:freeToBytes#
 
     byteArrayFreeToBytes                    ,
@@ -112,7 +107,7 @@ module GI.GLib.Structs.ByteArray
 
 -- ** data #attr:data#
 -- | a pointer to the element data. The data may be moved as
---     elements are added to the t'GI.GLib.Structs.ByteArray.ByteArray'
+--     elements are added to the @GByteArray@
 
 #if defined(ENABLE_OVERLOADING)
     byteArray_data                          ,
@@ -122,7 +117,7 @@ module GI.GLib.Structs.ByteArray
 
 
 -- ** len #attr:len#
--- | the number of elements in the t'GI.GLib.Structs.ByteArray.ByteArray'
+-- | the number of elements in the @GByteArray@
 
 #if defined(ENABLE_OVERLOADING)
     byteArray_len                           ,
@@ -196,7 +191,7 @@ instance B.Types.TypedObject ByteArray where
 
 instance B.Types.GBoxed ByteArray
 
--- | Convert 'ByteArray' to and from 'Data.GI.Base.GValue.GValue'. See 'Data.GI.Base.GValue.toGValue' and 'Data.GI.Base.GValue.fromGValue'.
+-- | Convert t'ByteArray' to and from 'Data.GI.Base.GValue.GValue'. See 'Data.GI.Base.GValue.toGValue' and 'Data.GI.Base.GValue.fromGValue'.
 instance B.GValue.IsGValue (Maybe ByteArray) where
     gvalueGType_ = c_g_byte_array_get_type
     gvalueSet_ gv P.Nothing = B.GValue.set_boxed gv (FP.nullPtr :: FP.Ptr ByteArray)
@@ -209,7 +204,7 @@ instance B.GValue.IsGValue (Maybe ByteArray) where
         
     
 
--- | Construct a `ByteArray` struct initialized to zero.
+-- | Construct a t'ByteArray' struct initialized to zero.
 newZeroByteArray :: MonadIO m => m ByteArray
 newZeroByteArray = liftIO $ callocBoxedBytes 16 >>= wrapBoxed ByteArray
 
@@ -260,7 +255,7 @@ instance AttrInfo ByteArrayDataFieldInfo where
         return v
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.GLib.Structs.ByteArray.data"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.29/docs/GI-GLib-Structs-ByteArray.html#g:attr:data"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.30/docs/GI-GLib-Structs-ByteArray.html#g:attr:data"
         })
 
 byteArray_data :: AttrLabelProxy "data"
@@ -309,7 +304,7 @@ instance AttrInfo ByteArrayLenFieldInfo where
         return v
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.GLib.Structs.ByteArray.len"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.29/docs/GI-GLib-Structs-ByteArray.html#g:attr:len"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-glib-2.0.30/docs/GI-GLib-Structs-ByteArray.html#g:attr:len"
         })
 
 byteArray_len :: AttrLabelProxy "len"
@@ -334,7 +329,7 @@ type ByteArrayAttributeList = ('[ '("data", ByteArrayDataFieldInfo), '("len", By
 --           , mayBeNull = False
 --           , argDoc =
 --               Documentation
---                 { rawDocText = Just "a #GByteArray" , sinceVersion = Nothing }
+--                 { rawDocText = Just "a byte array" , sinceVersion = Nothing }
 --           , argScope = ScopeTypeInvalid
 --           , argClosure = -1
 --           , argDestroy = -1
@@ -344,7 +339,7 @@ type ByteArrayAttributeList = ('[ '("data", ByteArrayDataFieldInfo), '("len", By
 --           }
 --       , Arg
 --           { argCName = "data"
---           , argType = TBasicType TUInt8
+--           , argType = TCArray False (-1) 2 (TBasicType TUInt8)
 --           , direction = DirectionIn
 --           , mayBeNull = False
 --           , argDoc =
@@ -377,109 +372,62 @@ type ByteArrayAttributeList = ('[ '("data", ByteArrayDataFieldInfo), '("len", By
 --           , transfer = TransferNothing
 --           }
 --       ]
--- Lengths: []
+-- Lengths: [ Arg
+--              { argCName = "len"
+--              , argType = TBasicType TUInt
+--              , direction = DirectionIn
+--              , mayBeNull = False
+--              , argDoc =
+--                  Documentation
+--                    { rawDocText = Just "the number of bytes to add"
+--                    , sinceVersion = Nothing
+--                    }
+--              , argScope = ScopeTypeInvalid
+--              , argClosure = -1
+--              , argDestroy = -1
+--              , argCallerAllocates = False
+--              , argCallbackUserData = False
+--              , transfer = TransferNothing
+--              }
+--          ]
 -- returnType: Just TByteArray
 -- throws : False
 -- Skip return : False
 
 foreign import ccall "g_byte_array_append" g_byte_array_append :: 
     Ptr GByteArray ->                       -- array : TByteArray
-    Word8 ->                                -- data : TBasicType TUInt8
+    Ptr Word8 ->                            -- data : TCArray False (-1) 2 (TBasicType TUInt8)
     Word32 ->                               -- len : TBasicType TUInt
     IO (Ptr GByteArray)
 
--- | Adds the given bytes to the end of the t'GI.GLib.Structs.ByteArray.ByteArray'.
+-- | Adds the given bytes to the end of the @GByteArray@.
 -- The array will grow in size automatically if necessary.
 byteArrayAppend ::
     (B.CallStack.HasCallStack, MonadIO m) =>
     ByteString
-    -- ^ /@array@/: a t'GI.GLib.Structs.ByteArray.ByteArray'
-    -> Word8
+    -- ^ /@array@/: a byte array
+    -> ByteString
     -- ^ /@data@/: the byte data to be added
-    -> Word32
-    -- ^ /@len@/: the number of bytes to add
     -> m ByteString
-    -- ^ __Returns:__ the t'GI.GLib.Structs.ByteArray.ByteArray'
-byteArrayAppend array data_ len = liftIO $ do
+    -- ^ __Returns:__ The @GByteArray@
+byteArrayAppend array data_ = liftIO $ do
+    let len = fromIntegral $ B.length data_
     array' <- packGByteArray array
-    result <- g_byte_array_append array' data_ len
+    data_' <- packByteString data_
+    result <- g_byte_array_append array' data_' len
     checkUnexpectedReturnNULL "byteArrayAppend" result
     result' <- unpackGByteArray result
     unrefGByteArray array'
+    freeMem data_'
     return result'
 
 #if defined(ENABLE_OVERLOADING)
 #endif
 
--- method ByteArray::free
--- method type : MemberFunction
--- Args: [ Arg
---           { argCName = "array"
---           , argType = TByteArray
---           , direction = DirectionIn
---           , mayBeNull = False
---           , argDoc =
---               Documentation
---                 { rawDocText = Just "a #GByteArray" , sinceVersion = Nothing }
---           , argScope = ScopeTypeInvalid
---           , argClosure = -1
---           , argDestroy = -1
---           , argCallerAllocates = False
---           , argCallbackUserData = False
---           , transfer = TransferNothing
---           }
---       , Arg
---           { argCName = "free_segment"
---           , argType = TBasicType TBoolean
---           , direction = DirectionIn
---           , mayBeNull = False
---           , argDoc =
---               Documentation
---                 { rawDocText =
---                     Just "if %TRUE the actual byte data is freed as well"
---                 , sinceVersion = Nothing
---                 }
---           , argScope = ScopeTypeInvalid
---           , argClosure = -1
---           , argDestroy = -1
---           , argCallerAllocates = False
---           , argCallbackUserData = False
---           , transfer = TransferNothing
---           }
---       ]
--- Lengths: []
--- returnType: Just (TBasicType TUInt8)
--- throws : False
--- Skip return : False
-
-foreign import ccall "g_byte_array_free" g_byte_array_free :: 
-    Ptr GByteArray ->                       -- array : TByteArray
-    CInt ->                                 -- free_segment : TBasicType TBoolean
-    IO Word8
-
--- | Frees the memory allocated by the t'GI.GLib.Structs.ByteArray.ByteArray'. If /@freeSegment@/ is
--- 'P.True' it frees the actual byte data. If the reference count of
--- /@array@/ is greater than one, the t'GI.GLib.Structs.ByteArray.ByteArray' wrapper is preserved but
--- the size of /@array@/ will be set to zero.
-byteArrayFree ::
-    (B.CallStack.HasCallStack, MonadIO m) =>
-    ByteString
-    -- ^ /@array@/: a t'GI.GLib.Structs.ByteArray.ByteArray'
-    -> Bool
-    -- ^ /@freeSegment@/: if 'P.True' the actual byte data is freed as well
-    -> m Word8
-    -- ^ __Returns:__ the element data if /@freeSegment@/ is 'P.False', otherwise
-    --          'P.Nothing'.  The element data should be freed using 'GI.GLib.Functions.free'.
-byteArrayFree array freeSegment = liftIO $ do
-    array' <- packGByteArray array
-    let freeSegment' = (P.fromIntegral . P.fromEnum) freeSegment
-    result <- g_byte_array_free array' freeSegment'
-    unrefGByteArray array'
-    return result
-
-#if defined(ENABLE_OVERLOADING)
-#endif
-
+-- XXX Could not generate method ByteArray::free
+{-  Bad introspection data: `TCArray False (-1) (-1) (TBasicType TUInt8)' is an array type, but contains no length information,
+    so it cannot be unpacked.
+-}
 -- method ByteArray::free_to_bytes
 -- method type : MemberFunction
 -- Args: [ Arg
@@ -489,7 +437,7 @@ byteArrayFree array freeSegment = liftIO $ do
 --           , mayBeNull = False
 --           , argDoc =
 --               Documentation
---                 { rawDocText = Just "a #GByteArray" , sinceVersion = Nothing }
+--                 { rawDocText = Just "a byte array" , sinceVersion = Nothing }
 --           , argScope = ScopeTypeInvalid
 --           , argClosure = -1
 --           , argDestroy = -1
@@ -507,23 +455,24 @@ foreign import ccall "g_byte_array_free_to_bytes" g_byte_array_free_to_bytes ::
     Ptr GByteArray ->                       -- array : TByteArray
     IO (Ptr GLib.Bytes.Bytes)
 
--- | Transfers the data from the t'GI.GLib.Structs.ByteArray.ByteArray' into a new immutable t'GI.GLib.Structs.Bytes.Bytes'.
+-- | Transfers the data from the @GByteArray@ into a new immutable
+-- t'GI.GLib.Structs.Bytes.Bytes'.
 -- 
--- The t'GI.GLib.Structs.ByteArray.ByteArray' is freed unless the reference count of /@array@/ is greater
--- than one, the t'GI.GLib.Structs.ByteArray.ByteArray' wrapper is preserved but the size of /@array@/
--- will be set to zero.
+-- The @GByteArray@ is freed unless the reference count of /@array@/ is greater
+-- than one, in which the @GByteArray@ wrapper is preserved but the size of
+-- /@array@/ will be set to zero.
 -- 
--- This is identical to using 'GI.GLib.Structs.Bytes.bytesNewTake' and 'GI.GLib.Functions.byteArrayFree'
--- together.
+-- This is identical to using 'GI.GLib.Structs.Bytes.bytesNewTake' and
+-- 'GI.GLib.Structs.ByteArray.byteArrayFree' together.
 -- 
 -- /Since: 2.32/
 byteArrayFreeToBytes ::
     (B.CallStack.HasCallStack, MonadIO m) =>
     ByteString
-    -- ^ /@array@/: a t'GI.GLib.Structs.ByteArray.ByteArray'
+    -- ^ /@array@/: a byte array
     -> m GLib.Bytes.Bytes
-    -- ^ __Returns:__ a new immutable t'GI.GLib.Structs.Bytes.Bytes' representing same
-    --     byte data that was in the array
+    -- ^ __Returns:__ The new immutable t'GI.GLib.Structs.Bytes.Bytes' representing
+    --   same byte data that was in the array
 byteArrayFreeToBytes array = liftIO $ do
     array' <- packGByteArray array
     result <- g_byte_array_free_to_bytes array'
@@ -545,11 +494,11 @@ byteArrayFreeToBytes array = liftIO $ do
 foreign import ccall "g_byte_array_new" g_byte_array_new :: 
     IO (Ptr GByteArray)
 
--- | Creates a new t'GI.GLib.Structs.ByteArray.ByteArray' with a reference count of 1.
+-- | Creates a new @GByteArray@ with a reference count of 1.
 byteArrayNew ::
     (B.CallStack.HasCallStack, MonadIO m) =>
     m ByteString
-    -- ^ __Returns:__ the new t'GI.GLib.Structs.ByteArray.ByteArray'
+    -- ^ __Returns:__ The new @GByteArray@
 byteArrayNew  = liftIO $ do
     result <- g_byte_array_new
     checkUnexpectedReturnNULL "byteArrayNew" result
@@ -569,7 +518,7 @@ byteArrayNew  = liftIO $ do
 --           , mayBeNull = False
 --           , argDoc =
 --               Documentation
---                 { rawDocText = Just "byte data for the array"
+--                 { rawDocText = Just "the byte data for the array"
 --                 , sinceVersion = Nothing
 --                 }
 --           , argScope = ScopeTypeInvalid
@@ -586,7 +535,9 @@ byteArrayNew  = liftIO $ do
 --           , mayBeNull = False
 --           , argDoc =
 --               Documentation
---                 { rawDocText = Just "length of @data" , sinceVersion = Nothing }
+--                 { rawDocText = Just "the length of @data"
+--                 , sinceVersion = Nothing
+--                 }
 --           , argScope = ScopeTypeInvalid
 --           , argClosure = -1
 --           , argDestroy = -1
@@ -602,7 +553,9 @@ byteArrayNew  = liftIO $ do
 --              , mayBeNull = False
 --              , argDoc =
 --                  Documentation
---                    { rawDocText = Just "length of @data" , sinceVersion = Nothing }
+--                    { rawDocText = Just "the length of @data"
+--                    , sinceVersion = Nothing
+--                    }
 --              , argScope = ScopeTypeInvalid
 --              , argClosure = -1
 --              , argDestroy = -1
@@ -621,21 +574,21 @@ foreign import ccall "g_byte_array_new_take" g_byte_array_new_take ::
     IO (Ptr GByteArray)
 
 -- | Creates a byte array containing the /@data@/.
--- After this call, /@data@/ belongs to the t'GI.GLib.Structs.ByteArray.ByteArray' and may no longer be
+-- After this call, /@data@/ belongs to the @GByteArray@ and may no longer be
 -- modified by the caller. The memory of /@data@/ has to be dynamically
 -- allocated and will eventually be freed with 'GI.GLib.Functions.free'.
 -- 
--- Do not use it if /@len@/ is greater than @/G_MAXUINT/@. t'GI.GLib.Structs.ByteArray.ByteArray'
--- stores the length of its data in @/guint/@, which may be shorter than
--- @/gsize/@.
+-- Do not use it if /@len@/ is greater than <http://developer.gnome.org/glib/stable/types.html#guint `G_MAXUINT`>.
+-- @GByteArray@ stores the length of its data in @guint@, which may be shorter
+-- than @gsize@.
 -- 
 -- /Since: 2.32/
 byteArrayNewTake ::
     (B.CallStack.HasCallStack, MonadIO m) =>
     ByteString
-    -- ^ /@data@/: byte data for the array
+    -- ^ /@data@/: the byte data for the array
     -> m ByteString
-    -- ^ __Returns:__ a new t'GI.GLib.Structs.ByteArray.ByteArray'
+    -- ^ __Returns:__ The new @GByteArray@
 byteArrayNewTake data_ = liftIO $ do
     let len = fromIntegral $ B.length data_
     data_' <- packByteString data_
@@ -657,7 +610,7 @@ byteArrayNewTake data_ = liftIO $ do
 --           , mayBeNull = False
 --           , argDoc =
 --               Documentation
---                 { rawDocText = Just "a #GByteArray" , sinceVersion = Nothing }
+--                 { rawDocText = Just "a byte array" , sinceVersion = Nothing }
 --           , argScope = ScopeTypeInvalid
 --           , argClosure = -1
 --           , argDestroy = -1
@@ -667,7 +620,7 @@ byteArrayNewTake data_ = liftIO $ do
 --           }
 --       , Arg
 --           { argCName = "data"
---           , argType = TBasicType TUInt8
+--           , argType = TCArray False (-1) 2 (TBasicType TUInt8)
 --           , direction = DirectionIn
 --           , mayBeNull = False
 --           , argDoc =
@@ -700,35 +653,53 @@ byteArrayNewTake data_ = liftIO $ do
 --           , transfer = TransferNothing
 --           }
 --       ]
--- Lengths: []
+-- Lengths: [ Arg
+--              { argCName = "len"
+--              , argType = TBasicType TUInt
+--              , direction = DirectionIn
+--              , mayBeNull = False
+--              , argDoc =
+--                  Documentation
+--                    { rawDocText = Just "the number of bytes to add"
+--                    , sinceVersion = Nothing
+--                    }
+--              , argScope = ScopeTypeInvalid
+--              , argClosure = -1
+--              , argDestroy = -1
+--              , argCallerAllocates = False
+--              , argCallbackUserData = False
+--              , transfer = TransferNothing
+--              }
+--          ]
 -- returnType: Just TByteArray
 -- throws : False
 -- Skip return : False
 
 foreign import ccall "g_byte_array_prepend" g_byte_array_prepend :: 
     Ptr GByteArray ->                       -- array : TByteArray
-    Word8 ->                                -- data : TBasicType TUInt8
+    Ptr Word8 ->                            -- data : TCArray False (-1) 2 (TBasicType TUInt8)
     Word32 ->                               -- len : TBasicType TUInt
     IO (Ptr GByteArray)
 
--- | Adds the given data to the start of the t'GI.GLib.Structs.ByteArray.ByteArray'.
+-- | Adds the given data to the start of the @GByteArray@.
 -- The array will grow in size automatically if necessary.
 byteArrayPrepend ::
     (B.CallStack.HasCallStack, MonadIO m) =>
     ByteString
-    -- ^ /@array@/: a t'GI.GLib.Structs.ByteArray.ByteArray'
-    -> Word8
+    -- ^ /@array@/: a byte array
+    -> ByteString
     -- ^ /@data@/: the byte data to be added
-    -> Word32
-    -- ^ /@len@/: the number of bytes to add
     -> m ByteString
-    -- ^ __Returns:__ the t'GI.GLib.Structs.ByteArray.ByteArray'
-byteArrayPrepend array data_ len = liftIO $ do
+    -- ^ __Returns:__ The @GByteArray@
+byteArrayPrepend array data_ = liftIO $ do
+    let len = fromIntegral $ B.length data_
     array' <- packGByteArray array
-    result <- g_byte_array_prepend array' data_ len
+    data_' <- packByteString data_
+    result <- g_byte_array_prepend array' data_' len
     checkUnexpectedReturnNULL "byteArrayPrepend" result
     result' <- unpackGByteArray result
     unrefGByteArray array'
+    freeMem data_'
     return result'
 
 #if defined(ENABLE_OVERLOADING)
@@ -743,7 +714,7 @@ byteArrayPrepend array data_ len = liftIO $ do
 --           , mayBeNull = False
 --           , argDoc =
 --               Documentation
---                 { rawDocText = Just "A #GByteArray" , sinceVersion = Nothing }
+--                 { rawDocText = Just "a byte array" , sinceVersion = Nothing }
 --           , argScope = ScopeTypeInvalid
 --           , argClosure = -1
 --           , argDestroy = -1
@@ -768,9 +739,9 @@ foreign import ccall "g_byte_array_ref" g_byte_array_ref ::
 byteArrayRef ::
     (B.CallStack.HasCallStack, MonadIO m) =>
     ByteString
-    -- ^ /@array@/: A t'GI.GLib.Structs.ByteArray.ByteArray'
+    -- ^ /@array@/: a byte array
     -> m ByteString
-    -- ^ __Returns:__ The passed in t'GI.GLib.Structs.ByteArray.ByteArray'
+    -- ^ __Returns:__ The passed in @GByteArray@
 byteArrayRef array = liftIO $ do
     array' <- packGByteArray array
     result <- g_byte_array_ref array'
@@ -792,7 +763,7 @@ byteArrayRef array = liftIO $ do
 --           , mayBeNull = False
 --           , argDoc =
 --               Documentation
---                 { rawDocText = Just "a #GByteArray" , sinceVersion = Nothing }
+--                 { rawDocText = Just "a byte array" , sinceVersion = Nothing }
 --           , argScope = ScopeTypeInvalid
 --           , argClosure = -1
 --           , argDestroy = -1
@@ -828,16 +799,16 @@ foreign import ccall "g_byte_array_remove_index" g_byte_array_remove_index ::
     Word32 ->                               -- index_ : TBasicType TUInt
     IO (Ptr GByteArray)
 
--- | Removes the byte at the given index from a t'GI.GLib.Structs.ByteArray.ByteArray'.
+-- | Removes the byte at the given index from a @GByteArray@.
 -- The following bytes are moved down one place.
 byteArrayRemoveIndex ::
     (B.CallStack.HasCallStack, MonadIO m) =>
     ByteString
-    -- ^ /@array@/: a t'GI.GLib.Structs.ByteArray.ByteArray'
+    -- ^ /@array@/: a byte array
     -> Word32
     -- ^ /@index_@/: the index of the byte to remove
     -> m ByteString
-    -- ^ __Returns:__ the t'GI.GLib.Structs.ByteArray.ByteArray'
+    -- ^ __Returns:__ The @GByteArray@
 byteArrayRemoveIndex array index_ = liftIO $ do
     array' <- packGByteArray array
     result <- g_byte_array_remove_index array' index_
@@ -858,7 +829,7 @@ byteArrayRemoveIndex array index_ = liftIO $ do
 --           , mayBeNull = False
 --           , argDoc =
 --               Documentation
---                 { rawDocText = Just "a #GByteArray" , sinceVersion = Nothing }
+--                 { rawDocText = Just "a byte array" , sinceVersion = Nothing }
 --           , argScope = ScopeTypeInvalid
 --           , argClosure = -1
 --           , argDestroy = -1
@@ -894,18 +865,18 @@ foreign import ccall "g_byte_array_remove_index_fast" g_byte_array_remove_index_
     Word32 ->                               -- index_ : TBasicType TUInt
     IO (Ptr GByteArray)
 
--- | Removes the byte at the given index from a t'GI.GLib.Structs.ByteArray.ByteArray'. The last
+-- | Removes the byte at the given index from a @GByteArray@. The last
 -- element in the array is used to fill in the space, so this function
--- does not preserve the order of the t'GI.GLib.Structs.ByteArray.ByteArray'. But it is faster
--- than 'GI.GLib.Functions.byteArrayRemoveIndex'.
+-- does not preserve the order of the @GByteArray@. But it is faster
+-- than 'GI.GLib.Structs.ByteArray.byteArrayRemoveIndex'.
 byteArrayRemoveIndexFast ::
     (B.CallStack.HasCallStack, MonadIO m) =>
     ByteString
-    -- ^ /@array@/: a t'GI.GLib.Structs.ByteArray.ByteArray'
+    -- ^ /@array@/: a byte array
     -> Word32
     -- ^ /@index_@/: the index of the byte to remove
     -> m ByteString
-    -- ^ __Returns:__ the t'GI.GLib.Structs.ByteArray.ByteArray'
+    -- ^ __Returns:__ The @GByteArray@
 byteArrayRemoveIndexFast array index_ = liftIO $ do
     array' <- packGByteArray array
     result <- g_byte_array_remove_index_fast array' index_
@@ -926,7 +897,7 @@ byteArrayRemoveIndexFast array index_ = liftIO $ do
 --           , mayBeNull = False
 --           , argDoc =
 --               Documentation
---                 { rawDocText = Just "a @GByteArray" , sinceVersion = Nothing }
+--                 { rawDocText = Just "a byte array" , sinceVersion = Nothing }
 --           , argScope = ScopeTypeInvalid
 --           , argClosure = -1
 --           , argDestroy = -1
@@ -981,19 +952,19 @@ foreign import ccall "g_byte_array_remove_range" g_byte_array_remove_range ::
     IO (Ptr GByteArray)
 
 -- | Removes the given number of bytes starting at the given index from a
--- t'GI.GLib.Structs.ByteArray.ByteArray'.  The following elements are moved to close the gap.
+-- @GByteArray@. The following elements are moved to close the gap.
 -- 
 -- /Since: 2.4/
 byteArrayRemoveRange ::
     (B.CallStack.HasCallStack, MonadIO m) =>
     ByteString
-    -- ^ /@array@/: a /@gByteArray@/
+    -- ^ /@array@/: a byte array
     -> Word32
     -- ^ /@index_@/: the index of the first byte to remove
     -> Word32
     -- ^ /@length@/: the number of bytes to remove
     -> m ByteString
-    -- ^ __Returns:__ the t'GI.GLib.Structs.ByteArray.ByteArray'
+    -- ^ __Returns:__ The @GByteArray@
 byteArrayRemoveRange array index_ length_ = liftIO $ do
     array' <- packGByteArray array
     result <- g_byte_array_remove_range array' index_ length_
@@ -1014,7 +985,7 @@ byteArrayRemoveRange array index_ length_ = liftIO $ do
 --           , mayBeNull = False
 --           , argDoc =
 --               Documentation
---                 { rawDocText = Just "a #GByteArray" , sinceVersion = Nothing }
+--                 { rawDocText = Just "a byte array" , sinceVersion = Nothing }
 --           , argScope = ScopeTypeInvalid
 --           , argClosure = -1
 --           , argDestroy = -1
@@ -1029,7 +1000,7 @@ byteArrayRemoveRange array index_ length_ = liftIO $ do
 --           , mayBeNull = False
 --           , argDoc =
 --               Documentation
---                 { rawDocText = Just "the new size of the #GByteArray"
+--                 { rawDocText = Just "the new size of the `GByteArray`"
 --                 , sinceVersion = Nothing
 --                 }
 --           , argScope = ScopeTypeInvalid
@@ -1050,15 +1021,15 @@ foreign import ccall "g_byte_array_set_size" g_byte_array_set_size ::
     Word32 ->                               -- length : TBasicType TUInt
     IO (Ptr GByteArray)
 
--- | Sets the size of the t'GI.GLib.Structs.ByteArray.ByteArray', expanding it if necessary.
+-- | Sets the size of the @GByteArray@, expanding it if necessary.
 byteArraySetSize ::
     (B.CallStack.HasCallStack, MonadIO m) =>
     ByteString
-    -- ^ /@array@/: a t'GI.GLib.Structs.ByteArray.ByteArray'
+    -- ^ /@array@/: a byte array
     -> Word32
-    -- ^ /@length@/: the new size of the t'GI.GLib.Structs.ByteArray.ByteArray'
+    -- ^ /@length@/: the new size of the @GByteArray@
     -> m ByteString
-    -- ^ __Returns:__ the t'GI.GLib.Structs.ByteArray.ByteArray'
+    -- ^ __Returns:__ The @GByteArray@
 byteArraySetSize array length_ = liftIO $ do
     array' <- packGByteArray array
     result <- g_byte_array_set_size array' length_
@@ -1079,7 +1050,7 @@ byteArraySetSize array length_ = liftIO $ do
 --           , mayBeNull = False
 --           , argDoc =
 --               Documentation
---                 { rawDocText = Just "number of bytes preallocated"
+--                 { rawDocText = Just "the number of bytes preallocated"
 --                 , sinceVersion = Nothing
 --                 }
 --           , argScope = ScopeTypeInvalid
@@ -1099,16 +1070,16 @@ foreign import ccall "g_byte_array_sized_new" g_byte_array_sized_new ::
     Word32 ->                               -- reserved_size : TBasicType TUInt
     IO (Ptr GByteArray)
 
--- | Creates a new t'GI.GLib.Structs.ByteArray.ByteArray' with /@reservedSize@/ bytes preallocated.
+-- | Creates a new @GByteArray@ with /@reservedSize@/ bytes preallocated.
 -- This avoids frequent reallocation, if you are going to add many
 -- bytes to the array. Note however that the size of the array is still
 -- 0.
 byteArraySizedNew ::
     (B.CallStack.HasCallStack, MonadIO m) =>
     Word32
-    -- ^ /@reservedSize@/: number of bytes preallocated
+    -- ^ /@reservedSize@/: the number of bytes preallocated
     -> m ByteString
-    -- ^ __Returns:__ the new t'GI.GLib.Structs.ByteArray.ByteArray'
+    -- ^ __Returns:__ The new @GByteArray@
 byteArraySizedNew reservedSize = liftIO $ do
     result <- g_byte_array_sized_new reservedSize
     checkUnexpectedReturnNULL "byteArraySizedNew" result
@@ -1128,7 +1099,7 @@ byteArraySizedNew reservedSize = liftIO $ do
 --           , mayBeNull = False
 --           , argDoc =
 --               Documentation
---                 { rawDocText = Just "a #GByteArray" , sinceVersion = Nothing }
+--                 { rawDocText = Just "a byte array" , sinceVersion = Nothing }
 --           , argScope = ScopeTypeInvalid
 --           , argClosure = -1
 --           , argDestroy = -1
@@ -1144,7 +1115,7 @@ byteArraySizedNew reservedSize = liftIO $ do
 --           , mayBeNull = False
 --           , argDoc =
 --               Documentation
---                 { rawDocText = Just "comparison function"
+--                 { rawDocText = Just "the comparison function"
 --                 , sinceVersion = Nothing
 --                 }
 --           , argScope = ScopeTypeCall
@@ -1166,7 +1137,7 @@ foreign import ccall "g_byte_array_sort" g_byte_array_sort ::
     IO ()
 
 -- | Sorts a byte array, using /@compareFunc@/ which should be a
--- @/qsort()/@-style comparison function (returns less than zero for first
+-- @qsort()@-style comparison function (returns less than zero for first
 -- arg is less than second arg, zero for equal, greater than zero if
 -- first arg is greater than second arg).
 -- 
@@ -1178,13 +1149,13 @@ foreign import ccall "g_byte_array_sort" g_byte_array_sort ::
 byteArraySort ::
     (B.CallStack.HasCallStack, MonadIO m) =>
     ByteString
-    -- ^ /@array@/: a t'GI.GLib.Structs.ByteArray.ByteArray'
+    -- ^ /@array@/: a byte array
     -> GLib.Callbacks.CompareFunc
-    -- ^ /@compareFunc@/: comparison function
+    -- ^ /@compareFunc@/: the comparison function
     -> m ()
 byteArraySort array compareFunc = liftIO $ do
     array' <- packGByteArray array
-    compareFunc' <- GLib.Callbacks.mk_CompareFunc (GLib.Callbacks.wrap_CompareFunc Nothing (GLib.Callbacks.drop_closures_CompareFunc compareFunc))
+    compareFunc' <- GLib.Callbacks.mk_CompareFunc (GLib.Callbacks.wrap_CompareFunc Nothing compareFunc)
     g_byte_array_sort array' compareFunc'
     safeFreeFunPtr $ castFunPtrToPtr compareFunc'
     unrefGByteArray array'
@@ -1202,7 +1173,7 @@ byteArraySort array compareFunc = liftIO $ do
 --           , mayBeNull = False
 --           , argDoc =
 --               Documentation
---                 { rawDocText = Just "a #GByteArray" , sinceVersion = Nothing }
+--                 { rawDocText = Just "a byte array" , sinceVersion = Nothing }
 --           , argScope = ScopeTypeInvalid
 --           , argClosure = -1
 --           , argDestroy = -1
@@ -1218,7 +1189,7 @@ byteArraySort array compareFunc = liftIO $ do
 --           , mayBeNull = False
 --           , argDoc =
 --               Documentation
---                 { rawDocText = Just "comparison function"
+--                 { rawDocText = Just "the comparison function"
 --                 , sinceVersion = Nothing
 --                 }
 --           , argScope = ScopeTypeCall
@@ -1235,7 +1206,7 @@ byteArraySort array compareFunc = liftIO $ do
 --           , mayBeNull = True
 --           , argDoc =
 --               Documentation
---                 { rawDocText = Just "data to pass to @compare_func"
+--                 { rawDocText = Just "the data to pass to @compare_func"
 --                 , sinceVersion = Nothing
 --                 }
 --           , argScope = ScopeTypeInvalid
@@ -1257,14 +1228,14 @@ foreign import ccall "g_byte_array_sort_with_data" g_byte_array_sort_with_data :
     Ptr () ->                               -- user_data : TBasicType TPtr
     IO ()
 
--- | Like 'GI.GLib.Functions.byteArraySort', but the comparison function takes an extra
+-- | Like 'GI.GLib.Structs.ByteArray.byteArraySort', but the comparison function takes an extra
 -- user data argument.
 byteArraySortWithData ::
     (B.CallStack.HasCallStack, MonadIO m) =>
     ByteString
-    -- ^ /@array@/: a t'GI.GLib.Structs.ByteArray.ByteArray'
+    -- ^ /@array@/: a byte array
     -> GLib.Callbacks.CompareDataFunc
-    -- ^ /@compareFunc@/: comparison function
+    -- ^ /@compareFunc@/: the comparison function
     -> m ()
 byteArraySortWithData array compareFunc = liftIO $ do
     array' <- packGByteArray array
@@ -1287,7 +1258,7 @@ byteArraySortWithData array compareFunc = liftIO $ do
 --           , mayBeNull = False
 --           , argDoc =
 --               Documentation
---                 { rawDocText = Just "a #GByteArray." , sinceVersion = Nothing }
+--                 { rawDocText = Just "a byte array" , sinceVersion = Nothing }
 --           , argScope = ScopeTypeInvalid
 --           , argClosure = -1
 --           , argDestroy = -1
@@ -1304,7 +1275,7 @@ byteArraySortWithData array compareFunc = liftIO $ do
 --               Documentation
 --                 { rawDocText =
 --                     Just
---                       "pointer to retrieve the number of\n   elements of the original array"
+--                       "the pointer to retrieve the number of\n   elements of the original array"
 --                 , sinceVersion = Nothing
 --                 }
 --           , argScope = ScopeTypeInvalid
@@ -1315,15 +1286,34 @@ byteArraySortWithData array compareFunc = liftIO $ do
 --           , transfer = TransferEverything
 --           }
 --       ]
--- Lengths: []
--- returnType: Just (TBasicType TUInt8)
+-- Lengths: [ Arg
+--              { argCName = "len"
+--              , argType = TBasicType TSize
+--              , direction = DirectionOut
+--              , mayBeNull = False
+--              , argDoc =
+--                  Documentation
+--                    { rawDocText =
+--                        Just
+--                          "the pointer to retrieve the number of\n   elements of the original array"
+--                    , sinceVersion = Nothing
+--                    }
+--              , argScope = ScopeTypeInvalid
+--              , argClosure = -1
+--              , argDestroy = -1
+--              , argCallerAllocates = False
+--              , argCallbackUserData = False
+--              , transfer = TransferEverything
+--              }
+--          ]
+-- returnType: Just (TCArray False (-1) 1 (TBasicType TUInt8))
 -- throws : False
 -- Skip return : False
 
 foreign import ccall "g_byte_array_steal" g_byte_array_steal :: 
     Ptr GByteArray ->                       -- array : TByteArray
     Ptr FCT.CSize ->                        -- len : TBasicType TSize
-    IO Word8
+    IO (Ptr Word8)
 
 -- | Frees the data in the array and resets the size to zero, while
 -- the underlying array is preserved for use elsewhere and returned
@@ -1333,18 +1323,20 @@ foreign import ccall "g_byte_array_steal" g_byte_array_steal ::
 byteArraySteal ::
     (B.CallStack.HasCallStack, MonadIO m) =>
     ByteString
-    -- ^ /@array@/: a t'GI.GLib.Structs.ByteArray.ByteArray'.
-    -> m ((Word8, FCT.CSize))
-    -- ^ __Returns:__ the element data, which should be
-    --     freed using 'GI.GLib.Functions.free'.
+    -- ^ /@array@/: a byte array
+    -> m ByteString
+    -- ^ __Returns:__ The allocated element data
 byteArraySteal array = liftIO $ do
     array' <- packGByteArray array
     len <- allocMem :: IO (Ptr FCT.CSize)
     result <- g_byte_array_steal array' len
     len' <- peek len
+    checkUnexpectedReturnNULL "byteArraySteal" result
+    result' <- (unpackByteStringWithLength len') result
+    freeMem result
     unrefGByteArray array'
     freeMem len
-    return (result, len')
+    return result'
 
 #if defined(ENABLE_OVERLOADING)
 #endif
@@ -1358,13 +1350,13 @@ byteArraySteal array = liftIO $ do
 --           , mayBeNull = False
 --           , argDoc =
 --               Documentation
---                 { rawDocText = Just "A #GByteArray" , sinceVersion = Nothing }
+--                 { rawDocText = Just "a byte array" , sinceVersion = Nothing }
 --           , argScope = ScopeTypeInvalid
 --           , argClosure = -1
 --           , argDestroy = -1
 --           , argCallerAllocates = False
 --           , argCallbackUserData = False
---           , transfer = TransferNothing
+--           , transfer = TransferEverything
 --           }
 --       ]
 -- Lengths: []
@@ -1385,12 +1377,11 @@ foreign import ccall "g_byte_array_unref" g_byte_array_unref ::
 byteArrayUnref ::
     (B.CallStack.HasCallStack, MonadIO m) =>
     ByteString
-    -- ^ /@array@/: A t'GI.GLib.Structs.ByteArray.ByteArray'
+    -- ^ /@array@/: a byte array
     -> m ()
 byteArrayUnref array = liftIO $ do
     array' <- packGByteArray array
     g_byte_array_unref array'
-    unrefGByteArray array'
     return ()
 
 #if defined(ENABLE_OVERLOADING)
